InfluxDB V3 Timeseries for MasterPiece — masterpiece documentation

# InfluxDB V3 Timeseries for MasterPiece

# InfluxDB V3 Plugin for MasterPiece

This project adds InfluxDB V3 timeseries recording functionality to MasterPiece framework.

## Usage

Pre-requisities:

- Create Influx cloud account, or install local Influx instance. Please consult the Influx site for more information on this.

To install the ‘masterpiece_influx’ plugin:

    pip install masterpiece_influx

Once installed, you can create ~/.yourapp/config/Influx.json configuration file to specify information needed for reading and writing time series data to your Influx database.

    {
      "token": "your token",
      "org": "your organization",
      "host": "https://eu-central-1-1.aws.cloud2.influxdata.com",
      "database": "your database"
    }

To import and instantiate Influx database for use:

    from masterpiece_influx import Influx

    db = Influx()

An example to write and read data:

    db.write_dict(name="temperature", tags={"sensor": "A1"}, fields={"value": 23.4}, ts="2024-12-14T12:00:00Z")
    data = db.read_dict(measurement="temperature", start_time="2024-12-01T00:00:00Z")

## Note

The masterpiece_influx.Influx class is an implementation of the abstract masterpiece.TimeSeries base class, designed for reading and writing time series data. The TimeSeries interface allows all time series operations in your application to remain implementation-independent.

## License

This project is licensed under the MIT License - see the LICENSE file for details.

# MIT License

Copyright (c) 2024, Juha Meskanen

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE

## Classes

# Index

- Index

- Module Index

- Search Page